Module models

Module models 

Modules

accept_invite_request
add_owner_to_folder_request
add_user_request
add_user_to_group_request
add_user_to_instance_group_request
agent_tool
ai_agent
ai_agent_input_transforms
ai_config
ai_provider
ai_provider_config
ai_provider_kind
ai_provider_model
ai_transform
alert
amqp_exchange
amqp_options
amqp_trigger
app_history
app_load_table_count_200_response
app_with_last_version
archive_flow_by_path_request
asset
asset_graph
asset_graph_assets_inner
asset_graph_dbt_edges_inner
asset_graph_edges_inner
asset_graph_macro_edges_inner
asset_graph_runnables_inner
asset_graph_runnables_inner_dbt
asset_graph_runnables_inner_macros_inner
asset_graph_test_edges_inner
asset_graph_triggers_inner
asset_graph_triggers_inner_one_of
asset_graph_triggers_inner_one_of_1
asset_kind
asset_progress
asset_schema_version
asset_schema_version_columns_inner
asset_usage_access_type
asset_usage_kind
assign_ghes_installation_request
attach_dev_workspace_request
audit_log
authentication_method
auto_invite_config
auto_pull_mode
auto_pull_settings
auto_pull_status
autoscaling_event
aws_auth_resource_type
aws_secrets_manager_settings
azure_arm_resource
azure_delete_subscription
azure_key_vault_settings
azure_list_subscriptions
azure_list_topics
azure_mode
azure_trigger
azure_trigger_data
batch_re_run_jobs_request
batch_re_run_jobs_request_script_options_by_path_value
blacklist_agent_token_request
branch_all
branch_all_branches_inner
branch_one
branch_one_branches_inner
call_mcp_tool_200_response
call_mcp_tool_request
cancel_queued_job_request
cancel_suspended_trigger_jobs_request
capture
capture_config
capture_trigger_kind
change_workspace_color_request
change_workspace_id_request
change_workspace_name_request
channel_info
check_s3_folder_exists_200_response
check_schema_contracts_200_response
check_schema_contracts_request
ci_test_result
commit_kafka_offsets_request
compare_summary
completed_job
concurrency_group
config
configs
connect_client_credentials_request
connect_slack_callback_request
connect_slack_request
connect_teams_request
contextual_variable
contract_warning
count_jobs_by_tag_200_response_inner
count_runnables_by_owner_200_response
count_search_logs_index_200_response
create_account_request
create_agent_token_request
create_app_raw_source_request
create_app_raw_source_request_value
create_app_request
create_datatable_migration_request
create_deployment_request_comment_request
create_deployment_request_request
create_flow_request
create_folder_request
create_input
create_instance_group_request
create_pg_database_request
create_protection_rule_request
create_resource
create_service_account_request
create_trigger_response
create_user_globally_request
create_variable
create_workspace
create_workspace_fork
create_workspace_fork_forked_datatables_inner
critical_alert
custom_instance_db
custom_instance_db_logs
custom_instance_db_tag
data_metric
data_table_schema
data_table_settings
data_table_settings_datatables_value
data_table_settings_datatables_value_database
data_table_settings_datatables_value_forked_from
data_table_table_schema
data_table_tables
database_health
datatable_migration
datatable_migration_with_status
dbt_asset_provenance
dbt_asset_provenance_data_tests_inner
dbt_warehouse_connection
dbt_warehouses_value
decline_invite_request
delete_gcp_subscription
delete_git_sync_repository_request
delete_invite_request
delete_variables_bulk_request
delivery_type
dependency_dependent
dependency_map
dependents_amount
deploy_event_kind
deploy_event_origin
deployment_request
deployment_request_assignee
deployment_request_comment
deployment_request_eligible_deployer
detach_dev_workspace_request
detailed_health_response
diff_raw_scripts_with_deployed_request
diff_raw_scripts_with_deployed_request_workspace_deps_inner
discover_ghes_installations_200_response_inner
discover_ghes_installations_200_response_inner_assigned_workspaces_inner
discover_mcp_o_auth_200_response
discover_mcp_o_auth_request
drop_forked_datatable_databases_request
duckdb_connection_settings_200_response
duckdb_connection_settings_request
duckdb_connection_settings_v2_200_response
duckdb_connection_settings_v2_request
ducklake_settings
ducklake_settings_ducklakes_value
ducklake_settings_ducklakes_value_catalog
ducklake_settings_ducklakes_value_maintenance
ducklake_settings_ducklakes_value_storage
dynamic_input_data
dynamic_input_data_runnable_ref
dynamic_input_data_runnable_ref_one_of
dynamic_input_data_runnable_ref_one_of_1
edit_amqp_trigger
edit_auto_invite_request
edit_copilot_config_200_response
edit_data_table_config_request
edit_data_table_config_request_renames_inner
edit_dbt_warehouses_request
edit_ducklake_config_request
edit_email_trigger
edit_error_handler
edit_error_handler_legacy
edit_error_handler_new
edit_flow
edit_git_sync_repository_request
edit_http_trigger
edit_instance_groups_request
edit_kafka_trigger
edit_large_file_storage_config_request
edit_mqtt_trigger
edit_nats_trigger
edit_postgres_trigger
edit_resource
edit_resource_type
edit_schedule
edit_slack_command_request
edit_sqs_trigger
edit_success_handler
edit_success_handler_legacy
edit_success_handler_new
edit_variable
edit_webhook_request
edit_websocket_trigger
edit_workspace_default_app_request
edit_workspace_deploy_ui_settings_request
edit_workspace_git_sync_config_request
edit_workspace_user
email_trigger
embed_token_response
endpoint_tool
error_handler
error_handler_config
execute_component_request
execute_component_request_raw_code
exists_email_local_part_request
exists_route_request
exists_username_request
exists_workspace_request
export_installation_200_response
export_pg_schema_request
exportable_completed_job
exportable_queued_job
exported_instance_group
exported_user
extended_jobs
external_jwt_token
file_resource_type_to_file_ext_map_200_response_value
file_upload_200_response
flow
flow_conversation
flow_conversation_message
flow_group
flow_metadata
flow_module
flow_module_debouncing
flow_module_mock
flow_module_skip_if
flow_module_suspend
flow_module_suspend_resume_form
flow_module_tool
flow_module_value
flow_note
flow_note_position
flow_note_size
flow_preview
flow_status
flow_status_failure_module
flow_status_module
flow_status_module_agent_actions_inner
flow_status_module_agent_actions_inner_one_of
flow_status_module_agent_actions_inner_one_of_1
flow_status_module_agent_actions_inner_one_of_2
flow_status_module_agent_actions_inner_one_of_3
flow_status_module_branch_chosen
flow_status_module_branchall
flow_status_module_flow_jobs_duration
flow_status_module_iterator
flow_status_retry
flow_value
flow_version
folder
folder_default_permissioned_as_inner
forloop_flow
gcp_trigger
gcp_trigger_data
generate_openapi_spec
get_ai_skill_200_response
get_all_topic_subscription
get_amqp_trigger_200_response
get_app_by_path_200_response
get_approval_info_200_response
get_approval_info_200_response_approval_conditions
get_approval_info_200_response_approvers_inner
get_audit_logs_s3_backfill_status_200_response
get_audit_logs_s3_status_200_response
get_azure_trigger_200_response
get_ci_test_results_batch_request
get_ci_test_results_batch_request_items_inner
get_cloud_quotas_200_response
get_completed_count_200_response
get_completed_job_result_maybe_200_response
get_completed_job_timing_200_response
get_copilot_settings_state_200_response
get_critical_alerts_200_response
get_datatable_full_schema_200_response_value_value
get_datatable_full_schema_200_response_value_value_columns_inner
get_datatable_full_schema_200_response_value_value_foreign_keys_inner
get_datatable_full_schema_200_response_value_value_foreign_keys_inner_columns_inner
get_datatable_full_schema_request
get_datatable_migrations_status_200_response
get_deploy_to_200_response
get_dev_workspace_200_response
get_draft_for_user_200_response
get_email_trigger_200_response
get_flow_all_logs_structured_200_response_inner
get_flow_all_results_200_response
get_flow_all_results_200_response_entries_inner
get_flow_by_path_200_response
get_flow_deployment_status_200_response
get_folder_permission_history_200_response_inner
get_folder_usage_200_response
get_gcp_trigger_200_response
get_ghes_config_200_response
get_git_commit_hash_200_response
get_git_sync_deploy_mode_200_response
get_git_sync_enabled_200_response
get_github_app_token_200_response
get_github_app_token_request
get_group_permission_history_200_response_inner
get_http_trigger_200_response
get_hub_app_by_id_200_response
get_hub_app_by_id_200_response_app
get_hub_flow_by_id_200_response
get_hub_script_by_path_200_response
get_index_disk_storage_sizes_200_response
get_index_storage_sizes_200_response
get_index_storage_sizes_200_response_job_index
get_indexer_status_200_response
get_indexer_status_200_response_job_indexer
get_instance_hash_200_response
get_job_metrics_200_response
get_job_metrics_request
get_job_updates_200_response
get_kafka_trigger_200_response
get_latest_key_renewal_attempt_200_response
get_log_cleanup_status_200_response
get_mcp_tools_200_response_inner
get_mcp_tools_200_response_inner_annotations
get_min_keep_alive_version_200_response
get_mqtt_trigger_200_response
get_nats_trigger_200_response
get_npm_package_filetree_200_response
get_npm_package_filetree_200_response_files_inner
get_npm_package_metadata_200_response
get_npm_proxy_config_200_response
get_o_auth_connect_200_response
get_object_storage_usage_200_response
get_object_storage_usage_200_response_folders_inner
get_offline_license_status_200_response
get_own_draft_200_response
get_postgres_trigger_200_response
get_premium_info_200_response
get_public_app_by_custom_path_200_response
get_public_settings_200_response
get_queue_count_200_response
get_queue_metrics_200_response_inner
get_queue_metrics_200_response_inner_values_inner
get_queue_position_200_response
get_resource_200_response
get_resource_history_200_response
get_resource_version_200_response
get_resume_urls_200_response
get_runnable_200_response
get_schedule_200_response
get_script_by_path_200_response
get_script_deployment_status_200_response
get_session_workspace_status_request
get_settings_200_response
get_shared_ui_200_response
get_shared_ui_version_200_response
get_sqs_trigger_200_response
get_stats_200_response
get_storage_usage_200_response
get_storage_usage_200_response_storages_inner
get_suspended_job_flow_200_response
get_threshold_alert_200_response
get_top_hub_scripts_200_response
get_top_hub_scripts_200_response_asks_inner
get_tutorial_progress_200_response
get_used_triggers_200_response
get_variable_200_response
get_websocket_trigger_200_response
get_workspace_default_app_200_response
get_workspace_encryption_key_200_response
get_workspace_fairness_events_200_response_inner
get_workspace_slack_oauth_config_200_response
ghes_installation_callback_request
git_repository_settings
git_repository_settings_settings
git_sync_object_type
github_app_stale_webhooks_200_response_inner
github_installations_inner
github_installations_inner_repositories_inner
github_repo_entry
global_offboard_preview
global_offboard_request
global_setting
global_user_change_email_request
global_user_info
global_user_rename_request
global_user_update_request
global_username_info_200_response
global_username_info_200_response_workspace_usernames_inner
google_calendar_entry
google_drive_file
google_drive_files_response
group
health_checks
health_status_response
hidden_item
hidden_items_summary
http_method
http_request_type
http_trigger
hub_script_kind
identity
impersonate_service_account_request
import_installation_request
import_pg_database_request
inline_script_args
input
input_transform
install_from_workspace_request
instance_ai_provider_summary
instance_ai_summary
instance_config
instance_group
instance_group_with_workspaces
invite_user_request
javascript_transform
job
job_one_of
job_one_of_1
job_search_hit
job_trigger_kind
jwks_response
kafka_trigger
language
large_file_storage
large_file_storage_secondary_storage_value
list_addable_instance_users_200_response_inner
list_ai_skills_200_response_inner
list_all_dedicated_with_deps_200_response_inner
list_all_workspace_dependencies_200_response_inner
list_asset_dispatch_edges_200_response_inner
list_assets_200_response
list_assets_200_response_assets_inner
list_assets_200_response_assets_inner_metadata
list_assets_200_response_assets_inner_usages_inner
list_assets_200_response_assets_inner_usages_inner_metadata
list_assets_200_response_next_cursor
list_assets_by_usage_200_response_inner_inner
list_assets_by_usage_request
list_assets_by_usage_request_usages_inner
list_available_teams_channels_200_response
list_available_teams_channels_200_response_channels_inner
list_available_teams_ids_200_response
list_available_teams_ids_200_response_teams_inner
list_blacklisted_agent_tokens_200_response_inner
list_data_metrics_200_response
list_data_metrics_200_response_next_cursor
list_data_tables_200_response_inner
list_dedicated_with_deps_200_response_inner
list_dispatch_events_200_response_inner
list_drafts_200_response_inner
list_favorite_assets_200_response_inner
list_flows_200_response_inner
list_hub_apps_200_response
list_hub_apps_200_response_apps_inner
list_hub_flows_200_response
list_hub_flows_200_response_flows_inner
list_hub_integrations_200_response_inner
list_log_files_200_response_inner
list_o_auth_connects_200_response_inner
list_o_auth_logins_200_response
list_o_auth_logins_200_response_oauth_inner
list_pipeline_folders_200_response_inner
list_resource_names_200_response_inner
list_run_assets_200_response
list_runnables_200_response
list_scripts_200_response_inner
list_scripts_200_response_inner_all_of_draft_users_inner
list_search_flow_200_response_inner
list_search_resource_200_response_inner
list_search_script_200_response_inner
list_selected_job_groups_200_response_inner
list_selected_job_groups_200_response_inner_schemas_inner
list_shared_ui_200_response
list_stored_files_200_response
list_stored_files_paged_200_response
list_worker_groups_200_response_inner
list_workspace_macros_200_response_inner
list_ws_specific_200_response_inner
listable_app
listable_raw_app
listable_resource
listable_variable
log_feature_usage_request
log_feature_usage_request_events_inner
log_search_hit
logged_wizard_status
login
login_with_oauth_request
main_arg_signature
main_arg_signature_args_inner
main_arg_signature_args_inner_typ
main_arg_signature_args_inner_typ_one_of
main_arg_signature_args_inner_typ_one_of_1
main_arg_signature_args_inner_typ_one_of_2
main_arg_signature_args_inner_typ_one_of_3
main_arg_signature_args_inner_typ_one_of_2_object
main_arg_signature_args_inner_typ_one_of_2_object_props_inner
main_arg_signature_args_inner_typ_one_of_2_object_props_inner_typ
main_arg_signature_args_inner_typ_one_of_2_object_props_inner_typ_one_of
main_arg_signature_args_inner_typ_one_of_3_list
materialized_partition
mcp_tool_value
memory_auto
memory_config
memory_manual
memory_message
memory_off
memory_transform
metric_data_point
metric_metadata
migrate_legacy_draft_request
mint_preview_sdk_token_request
move_captures_and_configs_request
mqtt_client_version
mqtt_qo_s
mqtt_subscribe_topic
mqtt_trigger
mqtt_v3_config
mqtt_v5_config
native_service_name
native_trigger
native_trigger_data
native_trigger_service_callback_request
native_trigger_with_external
nats_trigger
new_amqp_trigger
new_email_trigger
new_http_trigger
new_http_trigger_static_asset_config
new_kafka_trigger
new_mqtt_trigger
new_nats_trigger
new_postgres_trigger
new_schedule
new_script
new_script_assets_inner
new_sqs_trigger
new_token
new_token_impersonate
new_websocket_trigger
new_workspace_dependencies
next_cloud_event_type
obscured_job
offboard_affected_paths
offboard_preview
offboard_request
offboard_response
offboard_summary
offboard_token_info
open_flow
open_flow_w_path
openapi_http_route_filters
openapi_spec_format
openapi_v3_info
openapi_v3_info_contact
openapi_v3_info_license
operator_settings
partitions_in_range
partitions_in_range_partitions_inner
password_reset_response
path_flow
path_script
pick_hub_script_by_path_200_response
pipeline_recording_body
polars_client_kwargs
polars_connection_settings_200_response
polars_connection_settings_v2_200_response
polars_connection_settings_v2_200_response_storage_options
policy
policy_allowed_s3_keys_inner
pool_stats
postgres_trigger
preview
preview_inline
preview_schedule_request
project_logo_body
project_logo_body_logo
protection_rule_kind
protection_ruleset
provider_config
provider_transform
prune_versions_200_response
prune_versions_request
publication_data
publish_app_body
publish_draft_body
publish_flow_body
publish_flow_inner
publish_migration_body
publish_migrations_body
publish_raw_app_body
publish_resource_body
publish_resource_type_body
publish_resources_body
publish_script_body
publish_trigger_body
publish_triggers_body
push_config
query_hub_scripts_200_response_inner
query_resource_types_200_response_inner
queue_health
queued_job
quota_info
raw_script
raw_script_assets_inner
raw_script_for_dependencies
read_docs_page_200_response
readiness_health
record_dbt_run_progress_request_inner
recording_body
redirect_uri
refresh_token_request
relations
remove_blacklist_agent_token_request
remove_owner_to_folder_request
request_password_reset_request
reset_password_request
resolve_completed_jobs_request
resolve_npm_package_version_200_response
resource
resource_type
resource_version
restart_flow_at_step_request
restart_flow_at_step_request_nested_path_inner
restarted_from
restarted_from_branch_chosen
resume_suspended_request
resume_suspended_trigger_jobs_request
retry
retry_constant
retry_exponential
retry_if
rollback_datatable_migrations_200_response
run_audit_logs_s3_backfill_request
run_datatable_migrations_200_response
run_datatable_migrations_200_response_applied_inner
run_flow_dependencies_async_request
run_raw_script_dependencies_201_response
run_raw_script_dependencies_request
run_slack_message_test_job_200_response
run_slack_message_test_job_request
runnable_item
runnable_kind
runnable_type
s3_object
s3_permission_rule
s3_resource
scalar_metric
schedule
schedule_w_jobs
schedule_w_jobs_all_of_jobs
scope_definition
scope_domain
script
script_history
script_lang
script_module
search_docs_200_response
search_docs_200_response_results_inner
search_jobs_index_200_response
search_jobs_index_200_response_index_metadata
search_logs_index_200_response
secret_migration_failure
secret_migration_report
seed_full_diff_scan_200_response
send_message_to_conversation_request
set_capture_config_request
set_default_error_or_recovery_handler_request
set_environment_variable_request
set_global_request
set_http_trigger_mode_request
set_job_progress_request
set_login_type_for_user_request
set_password_request
set_public_app_rate_limit_request
set_schedule_enabled_request
set_threshold_alert_request
set_workspace_encryption_key_request
set_workspace_slack_oauth_config_request
set_ws_specific_request
setup_custom_instance_db_request
shared_drive_entry
sign_s3_objects_request
slack_token
slack_token_team
slot
slot_list
sqs_trigger
star_request
static_memory_transform
static_provider_transform
static_transform
stop_after_if
storage_file
storage_folder
submit_onboarding_data_request
subscription_mode
success_handler_config
sync_result
table_to_track_inner
team_info
teams_channel
template_script
test_amqp_connection_request
test_azure_connection
test_critical_channels_request_inner
test_data_table_connection_200_response
test_kafka_connection_request
test_license_key_request
test_postgres_connection_request
test_smtp_request
test_smtp_request_smtp
test_websocket_connection_request
timeseries_metric
toggle_workspace_error_handler_for_script_request
token_response
tool_value
trigger_extra_property
trigger_filter
trigger_filter_one_of
trigger_filter_one_of_1
trigger_filter_one_of_2
trigger_filter_one_of_3
trigger_filter_one_of_4
trigger_history_entry
trigger_mode
triggers_count
triggers_count_primary_schedule
truncated_token
unresolve_completed_jobs_request
update_app_raw_source_request
update_app_raw_source_request_value
update_app_request
update_draft_200_response
update_draft_request
update_flow_history_request
update_flow_request
update_folder_request
update_group_request
update_input
update_instance_group_request
update_protection_rule_request
update_script_history_request
update_shared_ui_request
update_token_label_request
update_token_scopes_request
upload_ai_skills_request
upload_ai_skills_request_skills_inner
upload_s3_file_from_app_200_response
upsert_datatable_migration_request
user
user_draft_item_kind
user_draft_overlay
user_draft_overlay_other_drafts_users_inner
user_source
user_usage
user_workspace_list
user_workspace_list_workspaces_inner
vault_settings
volume
webhook_event
webhook_filters
webhook_request_type
websearch_tool_value
websocket_heartbeat
websocket_trigger
websocket_trigger_initial_message
websocket_trigger_initial_message_any_of
websocket_trigger_initial_message_any_of_1
websocket_trigger_initial_message_any_of_1_runnable_result
whileloop_flow
windmill_file_metadata
windmill_file_preview
windmill_large_file
worker_ping
workers_health
workflow_status
workflow_task
workspace
workspace_comparison
workspace_default_scripts
workspace_dependencies
workspace_deploy_ui_settings
workspace_git_sync_settings
workspace_github_installation
workspace_info
workspace_integrations
workspace_invite
workspace_item_diff
workspace_mute_critical_alerts_ui_request
workspace_o_auth_config
workspace_offboard_preview
workspace_reassignment

Structs

AcceptInviteRequest
AddOwnerToFolderRequest
AddUserRequest
AddUserToGroupRequest
AddUserToInstanceGroupRequest
AgentTool
AgentTool : A tool available to an AI agent. Can be a flow module or an external MCP (Model Context Protocol) tool
AiAgent
AiAgent : AI agent step that can use tools to accomplish tasks. The agent receives inputs and can call any of its configured tools to complete the task
AiAgentInputTransforms
AiAgentInputTransforms : Input parameters for the AI agent mapped to their values
AiConfig
AiProviderConfig
AiProviderModel
AiTransform
AiTransform : Value resolved by the AI runtime for this input. The AI engine decides how to satisfy the parameter.
Alert
AmqpExchange
AmqpOptions
AmqpTrigger
AppHistory
AppLoadTableCount200Response
AppWithLastVersion
ArchiveFlowByPathRequest
Asset
AssetGraph
AssetGraphAssetsInner
AssetGraphDbtEdgesInner
AssetGraphEdgesInner
AssetGraphMacroEdgesInner
AssetGraphRunnablesInner
AssetGraphRunnablesInnerDbt
AssetGraphRunnablesInnerDbt : Set on a dbt script, which owns a whole project rather than a single output. Omitted otherwise.
AssetGraphRunnablesInnerMacrosInner
AssetGraphTestEdgesInner
AssetGraphTriggersInnerOneOf
AssetGraphTriggersInnerOneOf : Asset trigger edge (// on <asset>)
AssetGraphTriggersInnerOneOf1
AssetGraphTriggersInnerOneOf1 : Native trigger edge (schedule, email, kafka, …). path is the trigger row’s path.
AssetProgress
AssetSchemaVersion
AssetSchemaVersionColumnsInner
AssignGhesInstallationRequest
AttachDevWorkspaceRequest
AuditLog
AutoInviteConfig
AutoInviteConfig : Configuration for auto-inviting users to the workspace
AutoPullSettings
AutoPullStatus
AutoscalingEvent
AwsSecretsManagerSettings
AzureArmResource
AzureArmResource : An ARM resource the service principal can see.
AzureDeleteSubscription
AzureKeyVaultSettings
AzureListSubscriptions
AzureListTopics
AzureTrigger
AzureTrigger : An Azure Event Grid trigger that executes a script or flow when events arrive.
AzureTriggerData
AzureTriggerData : Data for creating or updating an Azure Event Grid trigger.
BatchReRunJobsRequest
BatchReRunJobsRequestScriptOptionsByPathValue
BlacklistAgentTokenRequest
BranchAll
BranchAll : Parallel branching where all branches execute simultaneously. Unlike BranchOne, all branches run regardless of conditions. Useful for executing independent tasks concurrently
BranchAllBranchesInner
BranchOne
BranchOne : Conditional branching where only the first matching branch executes. Branches are evaluated in order, and the first one with a true expression runs. If no branches match, the default branch executes
BranchOneBranchesInner
CallMcpTool200Response
CallMcpToolRequest
CancelQueuedJobRequest
CancelSuspendedTriggerJobsRequest
Capture
CaptureConfig
ChangeWorkspaceColorRequest
ChangeWorkspaceIdRequest
ChangeWorkspaceNameRequest
ChannelInfo
CheckS3FolderExists200Response
CheckSchemaContracts200Response
CheckSchemaContractsRequest
CiTestResult
CommitKafkaOffsetsRequest
CompareSummary
CompletedJob
ConcurrencyGroup
Config
Configs
ConnectClientCredentialsRequest
ConnectSlackCallbackRequest
ConnectSlackRequest
ConnectTeamsRequest
ContextualVariable
ContractWarning
ContractWarning : One save-time schema-contract warning: a consumer reference that does not match the referenced asset’s latest captured schema. schema_version/captured_at identify the capture the check ran against (as-of the producer’s last run, not its latest save).
CountJobsByTag200ResponseInner
CountRunnablesByOwner200Response
CountSearchLogsIndex200Response
CreateAccountRequest
CreateAgentTokenRequest
CreateAppRawSourceRequest
CreateAppRawSourceRequestValue
CreateAppRawSourceRequestValue : The raw app’s value. files maps each source path to its content and must contain an entry point; runnables and data are carried through unchanged.
CreateAppRequest
CreateDatatableMigrationRequest
CreateDeploymentRequestCommentRequest
CreateDeploymentRequestRequest
CreateFlowRequest
CreateFolderRequest
CreateInput
CreateInstanceGroupRequest
CreatePgDatabaseRequest
CreateProtectionRuleRequest
CreateResource
CreateServiceAccountRequest
CreateTriggerResponse
CreateTriggerResponse : Response returned when a native trigger is created
CreateUserGloballyRequest
CreateVariable
CreateWorkspace
CreateWorkspaceFork
CreateWorkspaceForkForkedDatatablesInner
CriticalAlert
CustomInstanceDb
CustomInstanceDbLogs
DataMetric
DataMetric : One // measure or // dimension declaration, as catalogued from the script that materializes the table. expr and filter are the author’s own SQL: a reader renders a measure as expr plus, when filter is set, a trailing FILTER (WHERE filter).
DataTableSchema
DataTableSettings
DataTableSettingsDatatablesValue
DataTableSettingsDatatablesValueDatabase
DataTableSettingsDatatablesValueForkedFrom
DataTableSettingsDatatablesValueForkedFrom : Fork origin info with schema snapshot
DataTableTableSchema
DataTableTables
DatabaseHealth
DatabaseHealth : Database health status
DatatableMigration
DatatableMigrationWithStatus
DbtAssetProvenance
DbtAssetProvenance : What dbt says about the model, snapshot, seed or source that produces (or, for a source, is read at) this relation. A dbt project is one runnable node with many model assets, so per-model metadata belongs here rather than on the script.
DbtAssetProvenanceDataTestsInner
DbtWarehouseConnection
DbtWarehousesValue
DeclineInviteRequest
DeleteGcpSubscription
DeleteGitSyncRepositoryRequest
DeleteInviteRequest
DeleteVariablesBulkRequest
DependencyDependent
DependencyMap
DependentsAmount
DeploymentRequest
DeploymentRequestAssignee
DeploymentRequestComment
DeploymentRequestEligibleDeployer
DetachDevWorkspaceRequest
DetailedHealthResponse
DetailedHealthResponse : Detailed health status response (always fresh, no caching)
DiffRawScriptsWithDeployedRequest
DiffRawScriptsWithDeployedRequestWorkspaceDepsInner
DiscoverGhesInstallations200ResponseInner
DiscoverGhesInstallations200ResponseInnerAssignedWorkspacesInner
DiscoverMcpOAuth200Response
DiscoverMcpOAuthRequest
DropForkedDatatableDatabasesRequest
DuckdbConnectionSettings200Response
DuckdbConnectionSettingsRequest
DuckdbConnectionSettingsV2Request
DuckdbConnectionSettingsV2200Response
DucklakeSettings
DucklakeSettingsDucklakesValue
DucklakeSettingsDucklakesValueCatalog
DucklakeSettingsDucklakesValueMaintenance
DucklakeSettingsDucklakesValueMaintenance : Scheduled maintenance (enterprise) - snapshot expiry, adjacent-file compaction and orphaned-file cleanup, run as a managed per-lake schedule
DucklakeSettingsDucklakesValueStorage
DynamicInputData
DynamicInputDataRunnableRefOneOf
DynamicInputDataRunnableRefOneOf1
EditAmqpTrigger
EditAutoInviteRequest
EditCopilotConfig200Response
EditDataTableConfigRequest
EditDataTableConfigRequestRenamesInner
EditDbtWarehousesRequest
EditDucklakeConfigRequest
EditEmailTrigger
EditErrorHandlerLegacy
EditErrorHandlerLegacy : Legacy flat format for editing error handler (deprecated, use new format)
EditErrorHandlerNew
EditErrorHandlerNew : New grouped format for editing error handler
EditFlow
EditGitSyncRepositoryRequest
EditHttpTrigger
EditInstanceGroupsRequest
EditKafkaTrigger
EditLargeFileStorageConfigRequest
EditMqttTrigger
EditNatsTrigger
EditPostgresTrigger
EditResource
EditResourceType
EditSchedule
EditSlackCommandRequest
EditSqsTrigger
EditSuccessHandlerLegacy
EditSuccessHandlerLegacy : Legacy flat format for editing success handler (deprecated, use new format)
EditSuccessHandlerNew
EditSuccessHandlerNew : New grouped format for editing success handler
EditVariable
EditWebhookRequest
EditWebsocketTrigger
EditWorkspaceDefaultAppRequest
EditWorkspaceDeployUiSettingsRequest
EditWorkspaceGitSyncConfigRequest
EditWorkspaceUser
EmailTrigger
EmbedTokenResponse
EndpointTool
ErrorHandlerConfig
ErrorHandlerConfig : Configuration for the workspace error handler
ExecuteComponentRequest
ExecuteComponentRequestRawCode
ExistsEmailLocalPartRequest
ExistsRouteRequest
ExistsUsernameRequest
ExistsWorkspaceRequest
ExportInstallation200Response
ExportPgSchemaRequest
ExportableCompletedJob
ExportableCompletedJob : Completed job with full data for export/import operations
ExportableQueuedJob
ExportableQueuedJob : Queued job with full data for export/import operations
ExportedInstanceGroup
ExportedUser
ExtendedJobs
ExternalJwtToken
FileResourceTypeToFileExtMap200ResponseValue
FileUpload200Response
Flow
FlowConversation
FlowConversationMessage
FlowGroup
FlowGroup : A semantic group of flow modules for organizational purposes. Does not affect execution — modules remain in their original position in the flow. Groups provide naming and collapsibility in the editor. Members are computed dynamically from all nodes on paths between start_id and end_id.
FlowMetadata
FlowModule
FlowModule : A single step in a flow. Can be a script, subflow, loop, or branch
FlowModuleDebouncing
FlowModuleDebouncing : Debounce configuration for this step (EE only)
FlowModuleMock
FlowModuleMock : Mock configuration for testing without executing the actual step
FlowModuleSkipIf
FlowModuleSkipIf : Conditionally skip this step based on previous results or flow inputs
FlowModuleSuspend
FlowModuleSuspend : Configuration for approval/resume steps that wait for user input
FlowModuleSuspendResumeForm
FlowModuleSuspendResumeForm : Form schema for collecting input when resuming
FlowModuleTool
FlowModuleTool : A tool implemented as a flow module (script, flow, etc.). The AI can call this like any other flow module
FlowNote
FlowNote : A sticky note attached to a flow for documentation and annotation
FlowNotePosition
FlowNotePosition : Position of the note in the flow editor
FlowNoteSize
FlowNoteSize : Size of the note in the flow editor
FlowPreview
FlowStatus
FlowStatusFailureModule
FlowStatusModule
FlowStatusModuleAgentActionsInnerOneOf
FlowStatusModuleAgentActionsInnerOneOf1
FlowStatusModuleAgentActionsInnerOneOf2
FlowStatusModuleAgentActionsInnerOneOf3
FlowStatusModuleBranchChosen
FlowStatusModuleBranchall
FlowStatusModuleFlowJobsDuration
FlowStatusModuleIterator
FlowStatusRetry
FlowValue
FlowValue : The flow structure containing modules and optional preprocessor/failure handlers
FlowVersion
Folder
FolderDefaultPermissionedAsInner
ForloopFlow
ForloopFlow : Executes nested modules in a loop over an iterator. Inside the loop, use ‘flow_input.iter.value’ to access the current iteration value, and ‘flow_input.iter.index’ for the index. Supports parallel execution for better performance on I/O-bound operations
GcpTrigger
GcpTrigger : A Google Cloud Pub/Sub trigger that executes a script or flow when messages are received.
GcpTriggerData
GcpTriggerData : Data for creating or updating a Google Cloud Pub/Sub trigger.
GenerateOpenapiSpec
GetAiSkill200Response
GetAllTopicSubscription
GetAmqpTrigger200Response
GetAppByPath200Response
GetApprovalInfo200Response
GetApprovalInfo200ResponseApprovalConditions
GetApprovalInfo200ResponseApproversInner
GetAuditLogsS3BackfillStatus200Response
GetAuditLogsS3Status200Response
GetAzureTrigger200Response
GetCiTestResultsBatchRequest
GetCiTestResultsBatchRequestItemsInner
GetCloudQuotas200Response
GetCompletedCount200Response
GetCompletedJobResultMaybe200Response
GetCompletedJobTiming200Response
GetCopilotSettingsState200Response
GetCriticalAlerts200Response
GetDatatableFullSchema200ResponseValueValue
GetDatatableFullSchema200ResponseValueValueColumnsInner
GetDatatableFullSchema200ResponseValueValueForeignKeysInner
GetDatatableFullSchema200ResponseValueValueForeignKeysInnerColumnsInner
GetDatatableFullSchemaRequest
GetDatatableMigrationsStatus200Response
GetDeployTo200Response
GetDevWorkspace200Response
GetDraftForUser200Response
GetEmailTrigger200Response
GetFlowAllLogsStructured200ResponseInner
GetFlowAllResults200Response
GetFlowAllResults200ResponseEntriesInner
GetFlowByPath200Response
GetFlowDeploymentStatus200Response
GetFolderPermissionHistory200ResponseInner
GetFolderUsage200Response
GetGcpTrigger200Response
GetGhesConfig200Response
GetGitCommitHash200Response
GetGitSyncDeployMode200Response
GetGitSyncEnabled200Response
GetGithubAppToken200Response
GetGithubAppTokenRequest
GetGroupPermissionHistory200ResponseInner
GetHttpTrigger200Response
GetHubAppById200Response
GetHubAppById200ResponseApp
GetHubFlowById200Response
GetHubScriptByPath200Response
GetIndexDiskStorageSizes200Response
GetIndexStorageSizes200Response
GetIndexStorageSizes200ResponseJobIndex
GetIndexerStatus200Response
GetIndexerStatus200ResponseJobIndexer
GetInstanceHash200Response
GetJobMetrics200Response
GetJobMetricsRequest
GetJobUpdates200Response
GetKafkaTrigger200Response
GetLatestKeyRenewalAttempt200Response
GetLogCleanupStatus200Response
GetMcpTools200ResponseInner
GetMcpTools200ResponseInnerAnnotations
GetMinKeepAliveVersion200Response
GetMqttTrigger200Response
GetNatsTrigger200Response
GetNpmPackageFiletree200Response
GetNpmPackageFiletree200ResponseFilesInner
GetNpmPackageMetadata200Response
GetNpmProxyConfig200Response
GetOAuthConnect200Response
GetObjectStorageUsage200Response
GetObjectStorageUsage200ResponseFoldersInner
GetOfflineLicenseStatus200Response
GetOwnDraft200Response
GetPostgresTrigger200Response
GetPremiumInfo200Response
GetPublicAppByCustomPath200Response
GetPublicSettings200Response
GetQueueCount200Response
GetQueueMetrics200ResponseInner
GetQueueMetrics200ResponseInnerValuesInner
GetQueuePosition200Response
GetResource200Response
GetResourceHistory200Response
GetResourceVersion200Response
GetResumeUrls200Response
GetRunnable200Response
GetSchedule200Response
GetScriptByPath200Response
GetScriptDeploymentStatus200Response
GetSessionWorkspaceStatusRequest
GetSettings200Response
GetSharedUi200Response
GetSharedUiVersion200Response
GetSqsTrigger200Response
GetStats200Response
GetStorageUsage200Response
GetStorageUsage200ResponseStoragesInner
GetSuspendedJobFlow200Response
GetThresholdAlert200Response
GetTopHubScripts200Response
GetTopHubScripts200ResponseAsksInner
GetTutorialProgress200Response
GetUsedTriggers200Response
GetVariable200Response
GetWebsocketTrigger200Response
GetWorkspaceDefaultApp200Response
GetWorkspaceEncryptionKey200Response
GetWorkspaceFairnessEvents200ResponseInner
GetWorkspaceSlackOauthConfig200Response
GhesInstallationCallbackRequest
GitRepositorySettings
GitRepositorySettingsSettings
GithubAppStaleWebhooks200ResponseInner
GithubInstallationsInner
GithubInstallationsInnerRepositoriesInner
GithubRepoEntry
GlobalOffboardPreview
GlobalOffboardRequest
GlobalSetting
GlobalUserChangeEmailRequest
GlobalUserInfo
GlobalUserRenameRequest
GlobalUserUpdateRequest
GlobalUsernameInfo200Response
GlobalUsernameInfo200ResponseWorkspaceUsernamesInner
GoogleCalendarEntry
GoogleDriveFile
GoogleDriveFilesResponse
Group
HealthChecks
HealthChecks : Detailed health checks
HealthStatusResponse
HealthStatusResponse : Health status response (cached with 5s TTL)
HiddenItem
HiddenItemsSummary
HttpTrigger
Identity
Identity : Pass-through module that returns its input unchanged. Useful for flow structure or as a placeholder
ImpersonateServiceAccountRequest
ImportInstallationRequest
ImportPgDatabaseRequest
InlineScriptArgs
Input
InstallFromWorkspaceRequest
InstanceAiProviderSummary
InstanceAiSummary
InstanceConfig
InstanceConfig : Unified instance configuration combining global settings and worker group configs
InstanceGroup
InstanceGroupWithWorkspaces
InviteUserRequest
JavascriptTransform
JavascriptTransform : JavaScript expression evaluated at runtime. Can reference previous step results via ‘results.step_id’ or flow inputs via ‘flow_input.property’. Inside for loops, use ‘flow_input.iter.value’ for the current iteration value (in while loops it equals ‘flow_input.iter.index’)
JobOneOf
JobOneOf1
JobSearchHit
JwksResponse
KafkaTrigger
LargeFileStorage
LargeFileStorageSecondaryStorageValue
ListAddableInstanceUsers200ResponseInner
ListAiSkills200ResponseInner
ListAllDedicatedWithDeps200ResponseInner
ListAllWorkspaceDependencies200ResponseInner
ListAssetDispatchEdges200ResponseInner
ListAssets200Response
ListAssets200ResponseAssetsInner
ListAssets200ResponseAssetsInnerMetadata
ListAssets200ResponseAssetsInnerUsagesInner
ListAssets200ResponseAssetsInnerUsagesInnerMetadata
ListAssets200ResponseNextCursor
ListAssets200ResponseNextCursor : Cursor for the next page (null if no more pages)
ListAssetsByUsage200ResponseInnerInner
ListAssetsByUsageRequest
ListAssetsByUsageRequestUsagesInner
ListAvailableTeamsChannels200Response
ListAvailableTeamsChannels200ResponseChannelsInner
ListAvailableTeamsIds200Response
ListAvailableTeamsIds200ResponseTeamsInner
ListBlacklistedAgentTokens200ResponseInner
ListDataMetrics200Response
ListDataMetrics200ResponseNextCursor
ListDataMetrics200ResponseNextCursor : Present when more rows may follow: pass its fields back as the cursor_* params. Absent means the catalog is exhausted.
ListDataTables200ResponseInner
ListDedicatedWithDeps200ResponseInner
ListDispatchEvents200ResponseInner
ListDrafts200ResponseInner
ListFavoriteAssets200ResponseInner
ListFlows200ResponseInner
ListHubApps200Response
ListHubApps200ResponseAppsInner
ListHubFlows200Response
ListHubFlows200ResponseFlowsInner
ListHubIntegrations200ResponseInner
ListLogFiles200ResponseInner
ListOAuthConnects200ResponseInner
ListOAuthLogins200Response
ListOAuthLogins200ResponseOauthInner
ListPipelineFolders200ResponseInner
ListResourceNames200ResponseInner
ListRunAssets200Response
ListRunnables200Response
ListScripts200ResponseInner
ListScripts200ResponseInnerAllOfDraftUsersInner
ListSearchFlow200ResponseInner
ListSearchResource200ResponseInner
ListSearchScript200ResponseInner
ListSelectedJobGroups200ResponseInner
ListSelectedJobGroups200ResponseInnerSchemasInner
ListSharedUi200Response
ListStoredFiles200Response
ListStoredFilesPaged200Response
ListWorkerGroups200ResponseInner
ListWorkspaceMacros200ResponseInner
ListWsSpecific200ResponseInner
ListableApp
ListableRawApp
ListableResource
ListableVariable
LogFeatureUsageRequest
LogFeatureUsageRequestEventsInner
LogSearchHit
Login
LoginWithOauthRequest
MainArgSignature
MainArgSignatureArgsInner
MainArgSignatureArgsInnerTypOneOf
MainArgSignatureArgsInnerTypOneOf1
MainArgSignatureArgsInnerTypOneOf2
MainArgSignatureArgsInnerTypOneOf3
MainArgSignatureArgsInnerTypOneOf2Object
MainArgSignatureArgsInnerTypOneOf2ObjectPropsInner
MainArgSignatureArgsInnerTypOneOf2ObjectPropsInnerTypOneOf
MaterializedPartition
McpToolValue
McpToolValue : Reference to an external MCP (Model Context Protocol) tool. The AI can call tools from MCP servers
MemoryAuto
MemoryAuto : Automatic context management
MemoryManual
MemoryManual : Explicit message history
MemoryMessage
MemoryMessage : A single message in conversation history
MemoryOff
MemoryOff : No conversation memory/context
MetricDataPoint
MetricMetadata
MigrateLegacyDraftRequest
MintPreviewSdkTokenRequest
MoveCapturesAndConfigsRequest
MqttSubscribeTopic
MqttTrigger
MqttV3Config
MqttV5Config
NativeTrigger
NativeTrigger : A native trigger stored in Windmill
NativeTriggerData
NativeTriggerData : Data for creating or updating a native trigger
NativeTriggerServiceCallbackRequest
NativeTriggerWithExternal
NativeTriggerWithExternal : Full trigger response containing both Windmill data and external service data
NatsTrigger
NewAmqpTrigger
NewEmailTrigger
NewHttpTrigger
NewHttpTriggerStaticAssetConfig
NewHttpTriggerStaticAssetConfig : Configuration for serving static assets (s3 bucket, storage path, filename)
NewKafkaTrigger
NewMqttTrigger
NewNatsTrigger
NewPostgresTrigger
NewSchedule
NewScript
NewScriptAssetsInner
NewSqsTrigger
NewToken
NewTokenImpersonate
NewWebsocketTrigger
NewWorkspaceDependencies
NextCloudEventType
ObscuredJob
OffboardAffectedPaths
OffboardPreview
OffboardRequest
OffboardResponse
OffboardSummary
OffboardTokenInfo
OpenFlow
OpenFlow : Top-level flow definition containing metadata, configuration, and the flow structure
OpenFlowWPath
OpenapiHttpRouteFilters
OpenapiV3Info
OpenapiV3InfoContact
OpenapiV3InfoLicense
OperatorSettings
PartitionsInRange
PartitionsInRangePartitionsInner
PasswordResetResponse
PathFlow
PathFlow : Reference to an existing flow by path. Use this to call another flow as a subflow
PathScript
PathScript : Reference to an existing script by path. Use this when calling a previously saved script instead of writing inline code
PickHubScriptByPath200Response
PipelineRecordingBody
PolarsClientKwargs
PolarsConnectionSettings200Response
PolarsConnectionSettingsV2200Response
PolarsConnectionSettingsV2200ResponseStorageOptions
Policy
PolicyAllowedS3KeysInner
PoolStats
PoolStats : Database connection pool statistics
PostgresTrigger
Preview
PreviewInline
PreviewScheduleRequest
ProjectLogoBody
ProjectLogoBodyLogo
ProjectLogoBodyLogo : the logo to set, or null to clear the project’s current logo
ProtectionRuleset
ProtectionRuleset : A workspace protection rule defining restrictions and bypass permissions
ProviderConfig
ProviderConfig : Complete AI provider configuration with resource reference and model selection
PruneVersions200Response
PruneVersionsRequest
PublicationData
PublishAppBody
PublishDraftBody
PublishFlowBody
PublishFlowInner
PublishMigrationBody
PublishMigrationBody : one best-effort data table migration attached to a project (per data table)
PublishMigrationsBody
PublishRawAppBody
PublishResourceBody
PublishResourceTypeBody
PublishResourcesBody
PublishScriptBody
PublishTriggerBody
PublishTriggersBody
PushConfig
PushConfig : Configuration for push delivery mode.
QueryHubScripts200ResponseInner
QueryResourceTypes200ResponseInner
QueueHealth
QueueHealth : Job queue status
QueuedJob
QuotaInfo
RawScript
RawScript : Inline script with code defined directly in the flow. Use ‘bun’ as default language if unspecified. The script receives arguments from input_transforms
RawScriptAssetsInner
RawScriptForDependencies
ReadDocsPage200Response
ReadinessHealth
ReadinessHealth : Server readiness status
RecordDbtRunProgressRequestInner
RecordingBody
RedirectUri
RefreshTokenRequest
Relations
RemoveBlacklistAgentTokenRequest
RemoveOwnerToFolderRequest
RequestPasswordResetRequest
ResetPasswordRequest
ResolveCompletedJobsRequest
ResolveNpmPackageVersion200Response
Resource
ResourceType
ResourceVersion
RestartFlowAtStepRequest
RestartFlowAtStepRequestNestedPathInner
RestartedFrom
RestartedFromBranchChosen
RestartedFromBranchChosen : For BranchOne nested restart — the branch that was originally chosen, used to lock branch evaluation.
ResumeSuspendedRequest
ResumeSuspendedTriggerJobsRequest
Retry
Retry : Retry configuration for failed module executions
RetryConstant
RetryConstant : Retry with constant delay between attempts
RetryExponential
RetryExponential : Retry with exponential backoff (delay doubles each time)
RetryIf
RetryIf : Conditional retry based on error or result
RollbackDatatableMigrations200Response
RunAuditLogsS3BackfillRequest
RunDatatableMigrations200Response
RunDatatableMigrations200ResponseAppliedInner
RunFlowDependenciesAsyncRequest
RunRawScriptDependencies201Response
RunRawScriptDependenciesRequest
RunSlackMessageTestJob200Response
RunSlackMessageTestJobRequest
RunnableItem
RunnableItem : A row in the merged runnables listing. type is the discriminator; kind-specific fields (hash/language/kind for scripts, execution_mode/ version for apps) are present only for that kind. edited_at is the unified last-updated time (a script’s created_at, a flow/app’s edit time).
S3Object
S3PermissionRule
S3Resource
ScalarMetric
Schedule
ScheduleWJobs
ScheduleWJobsAllOfJobs
ScopeDefinition
ScopeDomain
Script
ScriptHistory
ScriptModule
ScriptModule : An additional module file associated with a script
SearchDocs200Response
SearchDocs200ResponseResultsInner
SearchJobsIndex200Response
SearchJobsIndex200ResponseIndexMetadata
SearchJobsIndex200ResponseIndexMetadata : Metadata about the index current state
SearchLogsIndex200Response
SecretMigrationFailure
SecretMigrationReport
SeedFullDiffScan200Response
SendMessageToConversationRequest
SetCaptureConfigRequest
SetDefaultErrorOrRecoveryHandlerRequest
SetEnvironmentVariableRequest
SetGlobalRequest
SetHttpTriggerModeRequest
SetJobProgressRequest
SetLoginTypeForUserRequest
SetPasswordRequest
SetPublicAppRateLimitRequest
SetScheduleEnabledRequest
SetThresholdAlertRequest
SetWorkspaceEncryptionKeyRequest
SetWorkspaceSlackOauthConfigRequest
SetWsSpecificRequest
SetupCustomInstanceDbRequest
SharedDriveEntry
SignS3ObjectsRequest
SlackToken
SlackTokenTeam
Slot
SlotList
SqsTrigger
StarRequest
StaticMemoryTransform
StaticMemoryTransform : Static memory configuration passed directly to the AI agent
StaticProviderTransform
StaticProviderTransform : Static provider configuration passed directly to the AI agent
StaticTransform
StaticTransform : Static value passed directly to the step. Use for hardcoded values or resource references like ‘$res:path/to/resource’
StopAfterIf
StopAfterIf : Early termination condition for a module
StorageFile
StorageFolder
SubmitOnboardingDataRequest
SuccessHandlerConfig
SuccessHandlerConfig : Configuration for the workspace success handler
SyncResult
TableToTrackInner
TeamInfo
TeamsChannel
TemplateScript
TestAmqpConnectionRequest
TestAzureConnection
TestCriticalChannelsRequestInner
TestDataTableConnection200Response
TestKafkaConnectionRequest
TestLicenseKeyRequest
TestPostgresConnectionRequest
TestSmtpRequest
TestSmtpRequestSmtp
TestWebsocketConnectionRequest
TimeseriesMetric
ToggleWorkspaceErrorHandlerForScriptRequest
TokenResponse
TriggerExtraProperty
TriggerFilterOneOf
TriggerFilterOneOf1
TriggerFilterOneOf2
TriggerFilterOneOf3
TriggerFilterOneOf4
TriggerHistoryEntry
TriggersCount
TriggersCountPrimarySchedule
TruncatedToken
UnresolveCompletedJobsRequest
UpdateAppRawSourceRequest
UpdateAppRawSourceRequestValue
UpdateAppRawSourceRequestValue : The raw app’s value. files maps each source path (e.g. /index.tsx, /App.tsx, /package.json) to its content and must contain an entry point (/index.tsx, /index.ts or /index.js); runnables and data are carried through unchanged.
UpdateAppRequest
UpdateDraft200Response
UpdateDraftRequest
UpdateFlowHistoryRequest
UpdateFlowRequest
UpdateFolderRequest
UpdateGroupRequest
UpdateInput
UpdateInstanceGroupRequest
UpdateProtectionRuleRequest
UpdateScriptHistoryRequest
UpdateSharedUiRequest
UpdateTokenLabelRequest
UpdateTokenScopesRequest
UploadAiSkillsRequest
UploadAiSkillsRequestSkillsInner
UploadS3FileFromApp200Response
UpsertDatatableMigrationRequest
User
UserDraftOverlay
UserDraftOverlay : Overlay fields added to every "get by path" response that accepts the get_draft query parameter. The deployed payload is sent untouched in the response body; the authed user’s saved draft for this path — whatever shape the editor wrote — is attached as the sibling draft field when get_draft=true and a draft exists. The frontend pairs the two to present diff / reset / discard UI; the server never merges them. When no_deployed=true there is no deployed row at this path — the response body is a best-effort stand-in synthesized from the draft, and only draft is canonical. Callers should disable "diff vs deployed" UI in that case.
UserDraftOverlayOtherDraftsUsersInner
UserSource
UserUsage
UserWorkspaceList
UserWorkspaceListWorkspacesInner
VaultSettings
Volume
WebhookEvent
WebhookFilters
WebsearchToolValue
WebsearchToolValue : A tool implemented as a websearch tool. The AI can call this like any other websearch tool
WebsocketHeartbeat
WebsocketTrigger
WebsocketTriggerInitialMessage
WebsocketTriggerInitialMessageAnyOf
WebsocketTriggerInitialMessageAnyOf1
WebsocketTriggerInitialMessageAnyOf1RunnableResult
WhileloopFlow
WhileloopFlow : Executes nested modules repeatedly until stopped. The implicit iterator is the iteration counter, so ‘flow_input.iter.value’ equals ‘flow_input.iter.index’ (0, 1, 2, …) and never carries state. To carry state across iterations, a step reads its own previous-iteration result via ‘results.<its_own_id>’ with a first-iteration fallback - the loop’s stop_after_if must then be on that inner step (a plain single-step body with stop_after_if on the loop module does not resolve ‘results’ across iterations and never terminates); plain counters can instead be derived from ‘flow_input.iter.index’, which works in every configuration. stop_after_if is evaluated after each iteration - on the loop module ‘result’ is the last iteration’s result
WindmillFileMetadata
WindmillFilePreview
WindmillLargeFile
WorkerPing
WorkersHealth
WorkersHealth : Workers health status
WorkflowStatus
WorkflowTask
Workspace
WorkspaceComparison
WorkspaceDefaultScripts
WorkspaceDependencies
WorkspaceDeployUiSettings
WorkspaceGitSyncSettings
WorkspaceGithubInstallation
WorkspaceInfo
WorkspaceIntegrations
WorkspaceInvite
WorkspaceItemDiff
WorkspaceMuteCriticalAlertsUiRequest
WorkspaceOAuthConfig
WorkspaceOffboardPreview
WorkspaceReassignment

Enums

AiProvider
AiProviderKind
AiProviderKind : Supported AI provider types Supported AI provider types
AssetGraphTriggersInner
AssetKind
AssetUsageAccessType
AssetUsageKind
AuthenticationMethod
AutoPullMode
AwsAuthResourceType
AzureMode
AzureMode : Azure Event Grid trigger mode. Azure Event Grid trigger mode.
CaptureTriggerKind
CustomInstanceDbTag
DeliveryType
DeliveryType : Delivery mode for messages. ‘push’ for HTTP push delivery where messages are sent to a webhook endpoint, ‘pull’ for polling where the trigger actively fetches messages. Delivery mode for messages. ‘push’ for HTTP push delivery where messages are sent to a webhook endpoint, ‘pull’ for polling where the trigger actively fetches messages.
DeployEventKind
DeployEventKind : What a deploy event did to the path it is recorded against: write (the path holds an item after the event), delete (it does not), or rename_from (the path was vacated by a rename to another path). Create and update are not distinguished. Omitted when no such event has been recorded for that side, which counts as no evidence. What a deploy event did to the path it is recorded against: write (the path holds an item after the event), delete (it does not), or rename_from (the path was vacated by a rename to another path). Create and update are not distinguished. Omitted when no such event has been recorded for that side, which counts as no evidence.
DeployEventOrigin
DeployEventOrigin : Who caused a deploy event: authored (written in that workspace by the requester) or sync (applied there by a git-sync pull or a workspace-to-workspace deploy). Only an authored removal is evidence that the workspace dropped the item on purpose. Omitted when no such event has been recorded for that side. Who caused a deploy event: authored (written in that workspace by the requester) or sync (applied there by a git-sync pull or a workspace-to-workspace deploy). Only an authored removal is evidence that the workspace dropped the item on purpose. Omitted when no such event has been recorded for that side.
DynamicInputDataRunnableRef
EditErrorHandler
EditErrorHandler : Request body for editing the workspace error handler. Accepts both new grouped format and legacy flat format for backward compatibility. Request body for editing the workspace error handler. Accepts both new grouped format and legacy flat format for backward compatibility.
EditSuccessHandler
EditSuccessHandler : Request body for editing the workspace success handler. Accepts both new grouped format and legacy flat format for backward compatibility. Request body for editing the workspace success handler. Accepts both new grouped format and legacy flat format for backward compatibility.
ErrorHandler
FlowModuleValue
FlowModuleValue : The actual implementation of a flow step. Can be a script (inline or referenced), subflow, loop, branch, or special module type
FlowStatusModuleAgentActionsInner
GitSyncObjectType
HttpMethod
HttpRequestType
HubScriptKind
InputTransform
InputTransform : Maps input parameters for a step. Can be a static value or a JavaScript expression that references previous results or flow inputs
Job
JobTriggerKind
JobTriggerKind : job trigger kind (schedule, http, websocket…) job trigger kind (schedule, http, websocket…)
Language
LoggedWizardStatus
MainArgSignatureArgsInnerTyp
MainArgSignatureArgsInnerTypOneOf2ObjectPropsInnerTyp
MainArgSignatureArgsInnerTypOneOf3List
MemoryConfig
MemoryConfig : Conversation memory configuration
MemoryTransform
MemoryTransform : Memory configuration - can be static (MemoryConfig), JavaScript expression, or AI-determined
MqttClientVersion
MqttQoS
NativeServiceName
OpenapiSpecFormat
ProtectionRuleKind
ProviderTransform
ProviderTransform : Provider configuration - can be static (ProviderConfig), JavaScript expression, or AI-determined
RunnableKind
RunnableType
ScriptLang
SubscriptionMode
SubscriptionMode : The mode of subscription. ‘existing’ means using an existing GCP subscription, while ‘create_update’ involves creating or updating a new subscription. The mode of subscription. ‘existing’ means using an existing GCP subscription, while ‘create_update’ involves creating or updating a new subscription.
ToolValue
ToolValue : The implementation of a tool. Can be a flow module (script/flow) or an MCP tool reference
TriggerFilter
TriggerFilter : Either a leaf filter, matching a field of the message (parsed as JSON) against a value by equality (or superset, when the value is an object or array) — addressed by key for a top-level field or path for a dotted path into nested objects — or a group nesting sub-filters under a boolean operator (none_of matches when none of its sub-filters do). Either a leaf filter, matching a field of the message (parsed as JSON) against a value by equality (or superset, when the value is an object or array) — addressed by key for a top-level field or path for a dotted path into nested objects — or a group nesting sub-filters under a boolean operator (none_of matches when none of its sub-filters do).
TriggerMode
TriggerMode : job trigger mode job trigger mode
UserDraftItemKind
UserDraftItemKind : Closed set of item kinds a user can autosave as a draft. Mirrors the Postgres DRAFT_KIND enum and the backend UserDraftItemKind. Closed set of item kinds a user can autosave as a draft. Mirrors the Postgres DRAFT_KIND enum and the backend UserDraftItemKind.
WebhookRequestType
WebhookRequestType : The type of webhook request (define possible values here) The type of webhook request (define possible values here)